@@ -1,12 +1,12 @@
 package Log::Any::For::Builtins;
 
-our $DATE = '2015-01-12'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Proc::ChildError qw(explain_child_error);
 use String::Trim::More qw(ellipsis);
@@ -79,7 +79,7 @@ Log::Any::For::Builtins - (DEPRECATED) Log builtin functions
 
 =head1 VERSION
 
-This document describes version 0.10 of Log::Any::For::Builtins (from Perl distribution Builtin-Logged), released on 2015-01-12.
+This document describes version 0.11 of Log::Any::For::Builtins (from Perl distribution Builtin-Logged), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Builtin-Lo
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Builtin-Logged>.
+Source repository is at L<https://github.com/sharyanto/perl-Builtin-Logged>.
 
 =head1 BUGS
 
